@@ -1,6 +1,6 @@
 '''applications.py: common classes for ufw'''
 #
-# Copyright 2008-2011 Canonical Ltd.
+# Copyright 2008-2012 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -15,7 +15,6 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import ConfigParser
 import os
 import re
 import stat
@@ -23,6 +22,12 @@ import ufw.util
 from ufw.util import debug, warn
 from ufw.common import UFWError
 
+import sys
+if sys.version_info[0] < 3:  # pragma: no cover
+    import ConfigParser
+else:  # pragma: no cover
+    import configparser
+
 def get_profiles(profiles_dir):
     '''Get profiles found in profiles database.  Returns dictionary with
        profile name as key and tuples for fields
@@ -76,7 +81,11 @@ def get_profiles(profiles_dir):
 
         total_size += size
 
-        cdict = ConfigParser.RawConfigParser()
+        if sys.version_info[0] < 3:  # pragma: no cover
+            cdict = ConfigParser.RawConfigParser()
+        else:  # pragma: no cover
+            cdict = configparser.RawConfigParser()
+
         try:
             cdict.read(abs_path)
         except Exception:
@@ -121,7 +130,7 @@ def get_profiles(profiles_dir):
             if skip:
                 continue
 
-            if profiles.has_key(p):
+            if p in profiles:
                 warn_msg = _("Duplicate profile '%s', using last found") % (p)
                 warn(warn_msg)
 
@@ -130,7 +139,11 @@ def get_profiles(profiles_dir):
                 #debug("add '%s' = '%s' to '%s'" % (key, value, p))
                 pdict[key] = value
 
-            profiles[p] = pdict
+            try:
+                verify_profile(p, pdict)
+                profiles[p] = pdict
+            except UFWError as e:
+                warn(e)
 
     return profiles
 
@@ -158,7 +171,7 @@ def verify_profile(name, profile):
     app_fields = ['title', 'description', 'ports']
 
     for f in app_fields:
-        if not profile.has_key(f):
+        if f not in profile:
             err_msg = _("Profile '%(fn)s' missing required field '%(f)s'") % \
                         ({'fn': name, 'f': f})
 
@@ -169,19 +182,15 @@ def verify_profile(name, profile):
             raise UFWError(err_msg)
 
     ports = profile['ports'].split('|')
-    if len(ports) < 1:
-        err_msg = _("No ports found in profile '%s'") % (name)
-        return False
-
     try:
         for p in ports:
             (port, proto) = ufw.util.parse_port_proto(p)
-            # quick check if error in profile
-            #if not proto:
-            #    proto = "any"
+            # quick checks if error in profile
+            if proto == "any" and (':' in port or ',' in port):
+                raise UFWError(err_msg)
             rule = ufw.common.UFWRule("ACCEPT", proto, port)
             debug(rule)
-    except Exception, e:
+    except Exception as e:
         debug(e)
         err_msg = _("Invalid ports in profile '%s'") % (name)
         raise UFWError(err_msg)
@@ -192,7 +201,7 @@ def get_title(profile):
     '''Retrieve the title from the profile'''
     s = ""
     field = 'title'
-    if profile.has_key(field) and profile[field]:
+    if field in profile and profile[field]:
         s = profile[field]
     return s
 
@@ -200,7 +209,7 @@ def get_description(profile):
     '''Retrieve the description from the profile'''
     s = ""
     field = 'description'
-    if profile.has_key(field) and profile[field]:
+    if field in profile and profile[field]:
         s = profile[field]
     return s
 
@@ -208,7 +217,7 @@ def get_ports(profile):
     '''Retrieve a list of ports from a profile'''
     ports = []
     field = 'ports'
-    if profile.has_key(field) and profile[field]:
+    if field in profile and profile[field]:
         ports = profile[field].split('|')
 
     return ports
