@@ -1,5 +1,5 @@
 #
-# Copyright 2012 Canonical Ltd.
+# Copyright 2012-2016 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3,
@@ -103,11 +103,11 @@ class CommonTestCase(unittest.TestCase):
     def test__get_attrib(self):
         '''Test _get_attrib()'''
         res = self.rules["any"]._get_attrib()
-        search = "'-p all -j ACCEPT', action=allow, dapp=, direction=in, " + \
-                 "dport=any, dst=0.0.0.0/0, forward=False, interface_in=, " + \
-                 "interface_out=, logtype=, multi=False, position=0, " + \
-                 "protocol=any, remove=False, sapp=, sport=any, " + \
-                 "src=0.0.0.0/0, updated=False, v6=False"
+        search = "'-p all -j ACCEPT', action=allow, comment=, dapp=, " + \
+                 "direction=in, dport=any, dst=0.0.0.0/0, forward=False, " + \
+                 "interface_in=, interface_out=, logtype=, multi=False, " + \
+                 "position=0, protocol=any, remove=False, sapp=, " + \
+                 "sport=any, src=0.0.0.0/0, updated=False, v6=False"
         self.assertEquals(res, search, "'%s' != '%s'" % (res, search))
 
     def test_dup_rule(self):
@@ -334,7 +334,7 @@ class CommonTestCase(unittest.TestCase):
         '''Test set_interface()'''
         r = self.rules["any"]
         for if_type in ["in", "out"]:
-            for interface in ["eth0", "wlan1"]:
+            for interface in ["eth0", "wlan1", "br_lan"]:
                 r.set_interface(if_type, interface)
                 if if_type == "in":
                     self.assertEquals(interface, r.interface_in, "%s != %s" %
@@ -477,6 +477,11 @@ class CommonTestCase(unittest.TestCase):
             y.set_logtype(logtype)
             self.assertEquals(ufw.common.UFWRule.match(x, y), -1)
 
+        for comment in ['comment1', 'comment2']:
+            y = self.rules["full-any"].dup_rule()
+            y.set_comment(comment)
+            self.assertEquals(ufw.common.UFWRule.match(x, y), -2)
+
         y = self.rules["full-any"].dup_rule()
         y.set_port("456", loc="dst")
         self.assertEquals(ufw.common.UFWRule.match(x, y), 1)
@@ -701,6 +706,20 @@ class CommonTestCase(unittest.TestCase):
         self.assertEquals(self.rules['sapp'].src, t[3])
         self.assertEquals("out_eth0", t[4])
 
+        # also test with '_' in the name (LP: #1098472)
+        r = self.rules['sapp'].dup_rule()
+        t = r.get_app_tuple().split()
+        self.assertEquals("any", t[0])
+        self.assertEquals("0.0.0.0/0", t[1])
+        self.assertEquals(self.rules['sapp'].sapp, t[2])
+        self.assertEquals(self.rules['sapp'].src, t[3])
+        r.set_interface("out", "br_lan")
+        t = r.get_app_tuple().split()
+        self.assertEquals("any", t[0])
+        self.assertEquals("0.0.0.0/0", t[1])
+        self.assertEquals(self.rules['sapp'].sapp, t[2])
+        self.assertEquals(self.rules['sapp'].src, t[3])
+        self.assertEquals("out_br_lan", t[4])
 
 def test_main(): # used by runner.py
     tests.unit.support.run_unittest(
