@@ -1,5 +1,5 @@
 #
-# Copyright 2013 Canonical Ltd.
+# Copyright 2013-2016 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3,
@@ -15,6 +15,7 @@
 #
 
 import re
+import sys
 import unittest
 import tests.unit.support
 import ufw.parser
@@ -79,6 +80,14 @@ class ParserTestCase(unittest.TestCase):
         pr = c.parse(['status'])
         self.assertEquals('status', pr.action, "%s != 'status'" % (pr.action))
 
+    def test_ufwcommandbasic_parse_with_arg(self):
+        '''Test UFWCommand.parse() - basic with arg'''
+        parser = ufw.parser.UFWParser()
+        c = ufw.parser.UFWCommandBasic('enable')
+        tests.unit.support.check_for_exception(self, ValueError, \
+                                                   c.parse,
+                                                   ['enable', 'OpenSSH'])
+
     def test_ufwparser_response(self):
         '''Test UFWParserResponse.str()'''
         cmd = 'rule allow 22'
@@ -180,14 +189,19 @@ class ParserTestCase(unittest.TestCase):
 
             # First, feed the res rule into parse() (we need to split the
             # string but preserve quoted substrings
-            test_cmd = [cmd[0]] + \
-                       [p.strip("'") for p in re.split("( |'.*?')",
-                                                       res) if p.strip()]
+            if sys.version_info[0] < 3:
+                test_cmd = [cmd[0]] + \
+                           [p.strip("'").encode('utf-8') for p in re.split("( |'.*?')",
+                                                           res) if p.strip()]
+            else:
+                test_cmd = [cmd[0]] + \
+                           [p.strip("'") for p in re.split("( |'.*?')",
+                                                           res) if p.strip()]
             try:
                 self.parser.parse_command(test_cmd + [])
-            except Exception:
+            except ufw.common.UFWError:
                 self.assertTrue(False,
-                                "get_comand() returned invalid rule:\n" + \
+                                "get_command() returned invalid rule:\n" + \
                                 " orig=%s\n pr.data['rule']=%s\n result=%s" % \
                                 (cmd, pr.data['rule'], test_cmd))
 
@@ -207,6 +221,14 @@ class ParserTestCase(unittest.TestCase):
             # Note, cmd_compare contains the rules we get from
             # tests.unit.support.get_sample_rule_commands*
             cmd_compare = []
+            comment = ""  # store off command so we can add it at the end after
+                          # the massaging
+            if 'comment' in cmd:
+                comment_idx = cmd.index('comment')
+                comment = cmd[comment_idx + 1]
+                del cmd[comment_idx + 1]
+                del cmd[comment_idx]
+
             for i in cmd:
                 if ' ' in i:  # quote anything with a space for comparisons
                     cmd_compare.append("'%s'" % i)
@@ -324,9 +346,20 @@ class ParserTestCase(unittest.TestCase):
                    cmd_compare[tmp_in_idx] = 'out'
                    cmd_compare[tmp_in_idx + 2] = tmp_outif
 
-            if "%s %s" % (cmd[0], res) != " ".join(cmd_compare):
+            # add comment back
+            if comment != "":
+                cmd_compare.append('comment')
+                compare_str = " ".join(cmd_compare)
+                if sys.version_info[0] < 3:
+                    compare_str += " '%s'" % comment.decode('utf-8')
+                else:
+                    compare_str += " '%s'" % comment
+                cmd_compare.append(comment)
+            else:
+                compare_str = " ".join(cmd_compare)
+            if "%s %s" % (cmd[0], res) != compare_str:
                 errors.append(" \"%s %s\" != \"%s\" (orig=%s)" % (cmd[0], res,
-                    " ".join(cmd_compare), cmd))
+                    compare_str, cmd))
 
             #print("Result: rule %s" % res)
 
@@ -383,9 +416,17 @@ class ParserTestCase(unittest.TestCase):
                 ['rule', 'delete', 'allow', '22'],
                 ['rule', 'deny', 'from', 'any', 'port', 'domain', 'to', \
                  'any', 'port', 'tftp'],
+                ['rule', 'allow', 'to', 'any', 'proto', 'gre'],
                 ['rule', 'deny', 'to', 'any', 'proto', 'ipv6'],
-                ['rule', 'deny', 'to', 'any', 'proto', 'esp'],
+                ['rule', 'allow', 'to', 'any', 'proto', 'igmp'],
+                ['rule', 'reject', 'to', 'any', 'proto', 'esp'],
+                ['rule', 'deny', 'to', '224.0.0.1', 'proto', 'igmp'],
+                ['rule', 'deny', 'in', 'on', 'eth0', 'to', '224.0.0.1', \
+                 'proto', 'igmp'],
+                ['rule', 'allow', 'in', 'on', 'eth0', 'to', '192.168.0.1', \
+                 'proto', 'gre'],
                 ['rule', 'deny', 'to', 'any', 'proto', 'ah'],
+                ['rule', 'allow', 'out', 'on', 'br_lan'],
                ]
         count = 0
         for cmd in cmds:
@@ -459,12 +500,18 @@ class ParserTestCase(unittest.TestCase):
                   'proto', 'tcp'], ufw.common.UFWError),
                 (['rule', 'deny', 'to', '::1', 'proto', 'ipv6'],
                  ufw.common.UFWError),
+                (['rule', 'deny', 'to', '::1', 'proto', 'igmp'],
+                 ufw.common.UFWError),
                 (['rule', 'deny', 'to', 'any', 'port', '22', 'proto', 'ipv6'],
                  ufw.common.UFWError),
+                (['rule', 'deny', 'to', 'any', 'port', '22', 'proto', 'igmp'],
+                 ufw.common.UFWError),
                 (['rule', 'deny', 'to', 'any', 'port', '22', 'proto', 'esp'],
                  ufw.common.UFWError),
                 (['rule', 'deny', 'to', 'any', 'port', '22', 'proto', 'ah'],
                  ufw.common.UFWError),
+                (['rule', 'deny', 'to', 'any', 'port', '22', 'proto', 'gre'],
+                 ufw.common.UFWError),
                 (['rule', 'allow', 'to', '192.168.0.0/16', 'app', 'Samba',
                   'from', '192.168.0.0/16', 'port', 'tcpmux'],
                   ufw.common.UFWError),
@@ -540,6 +587,13 @@ class ParserTestCase(unittest.TestCase):
                                                self.parser.parse_command,
                                                c)
 
+    def test_route_delete_num(self):
+        '''Test route delete NUM'''
+        c = ['route', 'delete', '1']
+        tests.unit.support.check_for_exception(self, ufw.common.UFWError, \
+                                               self.parser.parse_command,
+                                               c)
+
     def test_app_parse(self):
         '''Test UFWCommandApp.parse()'''
         cmds = [
